# Implementierung

## Wahl des 480V-Sensorsystems

Für die Suche nach einem geeigneten 480V-Sensorsystem wurden verschiedene Kriterien definiert, die ein System erfüllen muss. Diese Kriterien sind:

1. Die Messwerte müssen unmittelbar abrufbar sein. 
  
    Wie bereits in der Theorie erwähnt, ist es wichtig, dass die Messung in Echtzeit erfolgt, damit die Verarbeitung und Filterung der Daten vor der Speicherung erfolgen kann. Zudem bietet dies die Möglichkeit, zeitnah Alarme aus möglichen Fehlzuständen zu generieren. Wenn die Messung nicht in Echtzeit erfolgt, dann müssten die Messwerte periodisch von der aufzeichnenden Hardware abgefragt werden. Das würde die Reaktionszeit des Systems verlangsamen und mögliche kurzzeitige Störungen könnten nicht erkannt werden.
    
2. Das System muss für industrielle Umgebungen geeignet sein.

    Da das System in einem industriellen Umfeld eingesetzt werden soll, muss es für diese Umgebung geeignet sein. Es muss eine lange wartungsarme Lebensdauer aufweisen, um mögliche Reperaturaufwände gering zu halten. Zudem muss es die entsprechenden Zertifizierungen besitzen, um die Sicherheit des Systems zu gewährleisten.

3. Das Sensorsystem muss über einen Feldbus, TCP/IP oder IO-Link angesprochen werden können.

    Da das System in ein bestehendes Feldbusnetzwerk eingebunden werden soll, muss es über einen standardisierten Feldbus verfügen. Dieser muss von der bestehenden Hardware unterstützt werden. In diesem Fall müssen die Feldbusprotokolle ProfiNet und EtherNet/IP unterstützt werden. Alternativ kann das System über IO-Link angesprochen werden. Dieser Standard ist in der Industrie weit verbreitet und wird auch in allen Anlagen von Laempe eingesetzt.

4. Das System muss internationale Versorgungsspannungen unterstützen.

    Da das System in Kernschießanlagen einesetzt wird, die in verschiedene Länder exportiert werden, muss das System eine vielzahl an Einspeisespannungen unterstützen. Da die Versorgungsspannung in den USA beispielsweise 480V beträgt, muss das System auch diese Spannung unterstützen. Eine Ausnahme bildet das kanadische Stromnetz, welches 600V verwendet. Für dieses Netz kann dem System später um eine entsprechende Spannungsumsetzung erweitert werden.

Unter diesen Kriterien sind nun diverse Energieerfassungssysteme recherchiert worden. Die Ergebnisse der Recherche sind in folgenden Tabelle zusammengefasst:

| Hersteller | Artikelnummer | Beschreibung | Feldbus | Kennwerte |
|------------|---------------|--------------|---------|-----------|
| Schneider Electric | [EM3550](https://www.se.com/de/de/download/document/PLSED310037EN_Web/) | Energiemonitor | Modbus RTU | 600V AC |
| Mitsubishi | [EMU4-HD1-MB](https://www.mitsubishielectric.com/fa/products/pmng/ems/pmerit/ecomonitor/ecomonitor_Light_2.html) | Energiemonitor | Modbus RTU / Modbus TCP / CC-Link / CC-Link IE | 480V AC |
| Mitsubishi | [EMU4-HM1-MB](http://dl.mitsubishielectric.com/dl/fa/document/catalog/ems/ym-c-y-0753/y0753b1706.pdf) | modularer Energiemonitor | Modbus RTU, CC-Link | 480V AC |
| Siemens | [7KT PAC1200](https://mall.industry.siemens.com/mall/en/de/Catalog/Products/10289825?activeTab=ProductInformation#Application) | mehrkanäliger Strommesssser | LAN/IP | 40/63 A |
| Siemens | [AI Energy Meter](https://assets.new.siemens.com/siemens/assets/api/uuid:c9a01401-9ad0-424b-9621-b6ee730381f9/energiemonitoring-quick-selection-guide-brochure.pdf) + [ET 200SP  IM 155-6 MF HF](https://support.industry.siemens.com/cs/mdm/109773210?c=152724557707&lc=de-WW) | Energiemeterkarte auf einem Interfacemodul | ProfiNet + EtherNet/IP | 480V AC |
| Janitza | [UMG801](https://www.janitza.de/umg-801.html) | Power Analyser, modular erweiterbar | Modbus RTU / TCP + OPC UA | 480V AC |
| Hager | [h3+](https://www.hager.ch/loesungen/zweckbau/schutzgeraete/leistungsschalter-h3+/423497.htm) | Leistungsschalter | Modbus RTU | 480V AC |
| Eaton | [NZM2 PXR25](https://datasheet.eaton.com/datasheet.php?model=192145&locale=de_DE) | Leistungsschalter | Modbus RTU | 690V 100A AC |

(Stand: 10.2021)

Leider waren zum Zeitpunkt der Recherche keine Energiesensoren mit IO-Link-Schnittstelle für den industriellen Gebrauch auffindbar. IO-Link ist jedoch ein Standard, der in der Industrie immer mehr an Bedeutung gewinnt und in Zukunft sicherlich auch in diesem Bereich eingesetzt werden wird. Sein Vorgänger, Modbus RTU, wird nicht mehr in den zu betrachtenden Kernschießmaschinen eingesetzt. Daher können alle Ergebnisse aus der Tabelle mit diesem Feldbus ausgeschlossen werden. Ähnlich dazu ist auch CC-Link nicht wünschenswert, da es nur bei Anlagen mit Mitsubishi Steuerungen zum Einsatz kommt. Dieser Feldbustyp existiert zwar unter den von Laempe hergesttellten Produkten; wird aber bei Kernschießmaschinen nur sehr selten eingesetzt. Außerdem unterstützen alle Mitsubishisteuerungen das EtherNet/IP-Protokoll [], auf das durch seine weit verbreitete Verwendung in Rockwell-Anlagen eher zurückgegriffen werden sollte. 

Die nächstbeste Kommunikationsschnittstelle, die zur direkten Anbindung an den datenverarbeitenden Computer geeignet ist, ist unter den Ergebnissen das OPC-UA vom `UMG801` Power Analyser. Dieses Protokoll ist ein offenes Protokoll das auf TCP/IP basiert, wodurch die die softwareseitige Anbindung an diese Einheit möglich wäre. Leider muss der UMG801 Power Analyser auch als möglicher Kandidat ausgeschlossen werden, da er die Echtzeit-Messdaten nur über seine Modbus RTU Schnittstelle und nicht über OPC-UA bereitstellt. Der letzte Strommesser mit TCP/IP-Anbindung ist der `7KT PAC1200` von Siemens. Dabei handelt es sich aber nur um eine Reihe von Stromsensoren, die nicht in der Lage sind die Spannung und somit die Momentanleistung der Einspeisung zu erfassen. Dies ist nicht erwünscht, da hier eine zusätzliche synchrone Erfassung der Drehspannungen nötig wäre.

Die letzte in Betracht kommende Option ist die Verwendung der Siemens AI-Energy-Meter-Karte auf einem Siemens Interfacemodul. Diese Karte erfüllt alle Kriterien und ist nebenbei eine sehr platzsparende Messeinrichtung. Sie überstützt einen Messbereich von $480\mathrm{V}$ und ist somit für den internationalen Einsatz geeignet. Als Interfacemodul, an dem die Energiemeterkarte aufgesteckt wird, wird das `ET 200SP IM 155-6 MF HF` eingesetzt. Dieses ist die *Multi-Fieldbus* Variante eines regulären Interfacemoduls und kann dadurch in ProfiNet- und EtherNet/IP-Netzwerken eingesetzt werden. Dadurch ist es möglich die Messwerte an die entsprechende zentrale Steuerung von Siemens oder Allen-Bradley zu übermitteln. 

## Wahl des 24V-Sensorsystems

| Hersteller | Artikelnummer | Bustyp | Nennstrom | Kanäle |
| ---------- | ------------- | ------ | -------- | ----- |

![Datenfluss](out/diagrams/datenfluss/Datenfluss.svg)

- Alternativen für Kleinstspannungskreise
  - Stromshunts mit ADC über IO-Link
  - Netzteile mit Modbus
  - elektronische Sicherungen mit IO-Link
- Wahl der Sensoren
  - IFM elektronische Sicherung mit IO-Link


## Verarbeitungssoftware

Die Software für dieses Projekt übernimmt die Aufgaben der Datenverarbeitung und -speicherung. Zudem müssen die aufgenommenen Messwerte von der zentralen Steuerung der Kernschießmaschine eingelesen werden. Das selbst geschriebene Programm "PLC-Connector" ist in diesem Abschnitt genauer beschrieben. Die Benutzerschnittstelle zum Benutzer des Systems kann im nachhinein durch ein generisches Interface zur Datenbank geschehen, da die dort enthaltenen Daten schon durch das Programm "PLC-Connector" und dessen entsprechende Signalverarbeitungsmodule aufbereitet sind. 

*PLC-Connector* ist modular aufgebaut, so dass verschiedene Komponenten einfach ausgetauscht werden können. Die Module sind in drei Kategorien unterteilt:

1. Inputs

    Ein *Input*-Modul stellt die Verbindung zu einer bestimmten Komponente der Anlage auf und bezieht über diese periodisch die Messwerte eines oder mehrerer Sensoren. Die Komponenten können beispielsweise Feldbusverteiler, netzwerkfähige Sensoren oder die zentrale Steuerung einer Anlage sein. Je nach Modul kommen unterschiedliche Protokolle zur Kommunikation zum Einsatz. Unter diesen sind zum Beispiel EtherNet/IP und das S7-Protokoll vertreten.

2. Middlewares

    Eine *Middleware* ist ein Algorithmus, der strukturierte Datensätze der aktiven *Input*-Module entgegen nimmt und die für die Auswertung interessante Informationen extrahiert. Eine erste *Middleware* nimmt beispielsweise die Werte mehrerer *Inputs* entgegen und führt eine zeitliche Korrelation durch. Die dadurch entstandenen Datenpakete können dann optional an weitere *Middlewares* weitergegeben werden, welche andere Analysen durchführen. Schließlich kann eine Middleware ihre Ergebnisse an die *Outputs* übergeben.

3. Outputs

    *Outputs* sind Datensenken, welche Datensätze von *Middlewares* entgegen nehmen und abspeichern. Ein *Output* archiviert beispielsweise die Datensätze in CSV Dateien und ein anderes sendet sie an eine Influxdb-Datenbank.

Die Module werden durch ein zentrales Python-Programm geladen, welches auch die initiale Konfiguration und die Datenübertragung zwischen den Modulen orchestriert. Ansonsten arbeiten die Module komplett autonom. Die Verbindungen und Parameter der Module sind in einer zentralen Konfigurationsdatei `config.yml` definiert. 